\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{thesis08}[2008/10/13 v.1.1]
\typeout{Document Style UAH Thesis. Escaped 9-Feb-1995 from D. G. Brown.}
\typeout{Adapted to LaTeX2e by Juanjo (contributor to LaTeX-Community)}
\typeout{www.latex-community.org}

% CLASS OPTIONS

%These are the different font size options
\DeclareOption{10pt}{\PassOptionsToClass{10pt}{report}}
\DeclareOption{11pt}{\PassOptionsToClass{11pt}{report}}
\DeclareOption{12pt}{\PassOptionsToClass{12pt}{report}}

%These are the different paper options, you will need letterpaper
%if you're using 8 1/2" x 11"
\DeclareOption{legalpaper}{\PassOptionsToClass{legalpaper}{report}}
\DeclareOption{letterpaper}{%
    \PassOptionsToClass{letterpaper}{report}}
\DeclareOption{executivepaper}{%
     \PassOptionsToClass{executivepaper}{report}}
\DeclareOption{a4paper}{\PassOptionsToClass{a4paper}{report}}
\DeclareOption{a5paper}{\PassOptionsToClass{a5paper}{report}}
\DeclareOption{b5paper}{\PassOptionsToClass{b5paper}{report}}
\DeclareOption{draft}{\PassOptionsToClass{draft}{report}}
\DeclareOption{final}{\PassOptionsToClass{final}{report}}
\DeclareOption{titlepage}{\PassOptionsToClass{titlepage}{report}}
\DeclareOption{notitlepage}{\PassOptionsToClass{notitlepage}{report}}
\DeclareOption{oneside}{\PassOptionsToClass{oneside}{report}}
\DeclareOption{twoside}{\PassOptionsToClass{twoside}{report}}
\DeclareOption{onecolumn}{\PassOptionsToClass{onecolumn}{report}}
\DeclareOption{twocolumn}{\PassOptionsToClass{twocolumn}{report}}
\DeclareOption{landscape}{\PassOptionsToClass{landscape}{report}}
\DeclareOption{openany}{\PassOptionsToClass{openany}{report}}
\DeclareOption{openright}{\PassOptionsToClass{openright}{report}}
\DeclareOption{leqno}{\PassOptionsToClass{leqno}{report}}
\DeclareOption{fleqno}{\PassOptionsToClass{fleqno}{report}}
\DeclareOption{openbib}{\PassOptionsToClass{openbib}{report}}
\ExecuteOptions{letterpaper,10pt,oneside,onecolumn,final,openany}
\ProcessOptions
\LoadClass{report}

% PAGE LAYOUT

\if@twoside 
   \oddsidemargin 21pt \evensidemargin 59pt \marginparwidth 85pt
\else 
   %\oddsidemargin 40.25pt \evensidemargin 40.25pt \marginparwidth 68pt
   \oddsidemargin 36pt \evensidemargin 36pt \marginparwidth 68pt %edit by JM to set margins to University requirements
\fi
\topmargin -28.5pt \headheight 12pt \headsep 25pt \footskip 26pt 
\textheight 637pt \textwidth 6 in  
\addtolength{\topmargin}{-12pt}

% SECTIONAL UNITS

% Part

\def\@part[#1]#2{%
    \ifnum \c@secnumdepth >-2\relax
       \refstepcounter{part}%
       \addcontentsline{toc}{part}{\thepart\hspace{1em}#1}%  
    \else
      \addcontentsline{toc}{part}{#1}%
    \fi
    \markboth{}{}%
    {\centering
     \interlinepenalty \@M
     \normalfont
     \ifnum \c@secnumdepth >-2\relax
       \large\bfseries\MakeUppercase{\partname}\nobreakspace\thepart
       \par
       %\vskip 20\p@ %edit by JM so that the required "Chapter" entry appeared in the correct vertical position
     \fi
     \large\bfseries\MakeUppercase{#2}\par}%
    \@endpart}
\def\@spart#1{%
    %\addcontentsline{toc}{part}{#1}% Uncomment for automatic inclusion in TOC
    {\centering
     \interlinepenalty \@M
     \normalfont
     \large\bfseries\MakeUppercase{#1}\par}%
    \@endpart}

% Chapter

\newif\if@inappendix \@inappendixfalse
\def\@chapter[#1]#2{
   \ifnum \c@secnumdepth >\m@ne
      \refstepcounter{chapter}
      \typeout{\@chapapp\space\thechapter.}
      \if@inappendix
         \addcontentsline{toc}{chapter}{%
            %\protect\appendixname\ \protect\numberline{\thechapter} #1}% JM
	    \protect\MakeUppercase{\appendixname}\ \protect\numberline{\thechapter:} #1}% edit by JM to add semi-colon after the appendix counter
      \else%
          \addcontentsline{toc}{chapter}{%
             \protect\numberline{\thechapter.} #1}%
      \fi
   \else
      \addcontentsline{toc}{chapter}{#1}%
   \fi
   \chaptermark{#1}%
   \if@twocolumn
      \@topnewpage[\@makechapterhead{#2}]
   \else 
      \@makechapterhead{#2} \@afterheading 
   \fi}
%Sets the chapter heading's font, and vertical space from the top of the page
\def\@makechapterhead#1{%
  %\vspace*{54\p@}%JM
  \vspace*{44\p@}%edit by JM to adjust the chapter heading to the correct vertical space from the top of the page for University requirements
  {\parindent \z@ \centering \normalfont
    \ifnum \c@secnumdepth >\m@ne
        \large\bfseries\MakeUppercase{\@chapapp}\space\thechapter
        \par\nobreak
        \vskip 28\p@
    \fi
    \interlinepenalty\@M
    \large\bfseries\MakeUppercase{#1}\par\nobreak
    \vskip 28\p@}}

\def\@makeschapterhead#1{%
  %\vspace*{54\p@}%JM
  \vspace*{44\p@}%edit by JM to adjust the chapter heading to the correct vertical space from the top of the page for University requirements
  {\parindent \z@ \centering
    \normalfont
    \interlinepenalty\@M
    \large\bfseries\MakeUppercase{#1}\par\nobreak
    \vskip 28\p@}}

% Section, subsection, etc.

\renewcommand\section{\@startsection{section}{1}{\z@}%
   %{3.5ex plus 1ex minus .2ex}{1.5ex plus .2ex}% JM
   {12pt plus 2pt}{2pt  plus 2pt}%edit by JM to make sections appear with the correct vertical space for University requirements
   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
   {3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}%
   {\normalfont\large\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
   {3.25ex plus 1ex minus .2ex}{1.5ex plus .2ex}%
   {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
   {3.25ex plus 1ex minus .2ex}{-1em}%
   {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}%
   {\parindent}{3.25ex plus 1ex minus .2ex}{-1em}%
   {\normalfont\normalsize\bfseries}}

% Associated counters

\setcounter{secnumdepth}{3}
\renewcommand\thesection{\thechapter.\Alph{section}}
\renewcommand\thesubsubsection{\thesubsection.\alph{subsubsection}}

% APPENDIX

\renewcommand\appendix{\par
  \setcounter{chapter}{0}%
  \setcounter{section}{0}%
  \gdef\@chapapp{\appendixname}%
  \gdef\thechapter{\@Alph\c@chapter}
  \@inappendixtrue
  \part*{Appendices}}

% TABLE OF CONTENTS

\setcounter{tocdepth}{3}

\renewcommand\contentsname{Table of Contents}
\newcommand{\headcontentsname}{Contents}
\renewcommand\tableofcontents{%
   \if@twocolumn
      \@restonecoltrue\onecolumn
   \else
      \@restonecolfalse
   \fi
   \chapter*{\contentsname
      \@mkboth{\MakeUppercase\headcontentsname}%
              {\MakeUppercase\headcontentsname}}%
   \hspace*{\fill}\textbf{Page}\par
   \@starttoc{toc}\if@restonecol\twocolumn\fi}

\renewcommand*\l@part[2]{%
  \ifnum \c@tocdepth >-2\relax
    \addpenalty{-\@highpenalty}%
    \vskip 1.0em \@plus\p@ % JM
    %\addvspace{2.25em \@plus\p@}% edit by JM so that the "Chapter" requirement shows up correctly in the table of contents
    \setlength\@tempdima{3em}%
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      {\leavevmode
       %\large \bfseries \MakeUppercase{#1}\hfil% edit by JM so that the "Chapter" requirement shows up correctly in the table of contents
       \bfseries #1\hfil%
       \hb@xt@\@pnumwidth{\hss #2}}\par
       \nobreak
         \global\@nobreaktrue
         \everypar{\global\@nobreakfalse\everypar{}}%
    \endgroup
  \fi}
  
\def\tocdots{\leaders\hbox{$\m@th\mkern \@dotsep mu\hbox{.}%
   \mkern \@dotsep mu$}\hfill}
\renewcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 1.0em \@plus\p@
    %\setlength\@tempdima{2.5em}%JM
    \setlength\@tempdima{2.em}%edit by JM to move chapter titles closer to the chapter number in the table of contents and make it look like the University example TOC
    \begingroup
      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      %\leavevmode \bfseries
      \leavevmode % edit by JM to remove bold face on dots in table of content and make the TOC like the University example
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      %\textbf{\MakeUppercase{#1}}\nobreak\tocdots\nobreak% JM
      \textbf{#1}\nobreak\tocdots\nobreak%edit by JM removing the \MakeUpperCase{#1} so that the List of Figures, List of Tables, and List of Symbols weren't forced to all caps for University requirements
      \hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}
\renewcommand*\l@section{\@dottedtocline{1}{2.5em}{3 em}}
\renewcommand*\l@subsection{\@dottedtocline{2}{5.5em}{4.0em}}
\renewcommand*\l@subsubsection{\@dottedtocline{3}{9.5em}{5em}}
\renewcommand*\l@paragraph{\@dottedtocline{4}{14.5em}{6em}}
\renewcommand*\l@subparagraph{\@dottedtocline{5}{20.5em}{7em}}

% LIST OF FIGURES AND LIST OF TABLES

\renewcommand\listoffigures{%
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\listfigurename}%
      \@mkboth{\MakeUppercase\listfigurename}%
              {\MakeUppercase\listfigurename}%
    {\noindent \bfseries Figure \hfill Page}\par%
    \addcontentsline{toc}{chapter}{\listfigurename}
    \@starttoc{lof}%
    \if@restonecol\twocolumn\fi}
    
\renewcommand*\l@figure{\@dottedtocline{1}{0em}{2.5em}}

\renewcommand\listoftables{%
    \if@twocolumn
      \@restonecoltrue\onecolumn
    \else
      \@restonecolfalse
    \fi
    \chapter*{\listtablename}%
      \@mkboth{\MakeUppercase\listtablename}%
              {\MakeUppercase\listtablename}%
    {\noindent \bfseries Table \hfill Page}\par%
    \addcontentsline{toc}{chapter}{\listtablename}
    \@starttoc{lot}%
    \if@restonecol\twocolumn\fi}
    
\let\l@table\l@figure

% BIBLIOGRAPHY

%\renewcommand\bibname{References} % JM
\renewcommand\bibname{REFERENCES} % edit by JM to make the entry into the table of contents all caps for University requirements
\renewenvironment{thebibliography}[1]
     {\chapter*{\bibname}%
      \@mkboth{\MakeUppercase\bibname}{\MakeUppercase\bibname}%
      \addcontentsline{toc}{chapter}{\bibname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \setlength{\itemsep}{0.6\itemsep}
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}

% CAPTIONS

\setlength\abovecaptionskip{24\p@} % 10pt in the report class
\setlength\belowcaptionskip{24\p@} %  0pt
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{#1 #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1 #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}

\endinput
